@@ -2,7 +2,6 @@
 	Algorithms!
 */
 
-
 #include "comp_plain.h"
 #include "comp_rle.h"
 #include "comp_delta.h"
@@ -22,6 +21,7 @@
 #include "comp_text.h"
 #include "comp_fail.h"
 
+#ifdef __DACT_C
 int (*(algorithms[256]))()={    comp_plain_algo,
                                 comp_rle_algo,
                                 comp_delta_algo,
@@ -30,25 +30,25 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 				comp_zlib_algo,
 				comp_mzlib_algo,
 #else
-				comp_fail_algo,
-				comp_fail_algo,
+				DACT_FAILED_ALGO,
+				DACT_FAILED_ALGO,
 #endif
 				comp_snibble_algo,
 				comp_range_algo,
 #ifdef USE_ZLIB
 				comp_mzlib2_algo,
 #else
-				comp_fail_algo,
+				DACT_FAILED_ALGO,
 #endif
 #ifdef USE_BZLIB
 				comp_bzlib_algo,
 #else
-				comp_fail_algo,
+				DACT_FAILED_ALGO,
 #endif
 #ifdef DEBUG
 				comp_factor_algo,
 #else
-				comp_fail_algo,
+				DACT_FAILED_ALGO,
 #endif
                                 NULL};
 
@@ -82,3 +82,7 @@ char *algorithm_names[256]={	"Uncompressed",
 #endif
 				NULL
 			};
+#else
+extern int (*(algorithms[256]))();
+extern char *algorithm_names[256];
+#endif
