@@ -1,3 +1,5 @@
+#include "dact.h"
+
 int bit_buffer_read(int bits);
 void bit_buffer_write(unsigned int val, unsigned int bits);
 int bit_buffer_size(void);
@@ -10,5 +12,5 @@ int byte_buffer_size(void);
 void byte_buffer_purge(void);
 
 #ifndef BYTE_BUFF_SIZE
-#define BYTE_BUFF_SIZE 4096
+#define BYTE_BUFF_SIZE MAX_DACT_BLK_SIZE*2
 #endif
