@@ -1,3 +1,10 @@
+#include "dact.h"
+#include "config.h"
+
+#if defined(USE_MODULES) && defined(COMP_MZLIB2_IS_MOD) && !defined(AS_MODULE)
+#define comp_mzlib2_algo DACT_FAILED_ALGO
+#else
 int comp_mzlib2_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_mzlib2_decompress(unsigned char *prev_block, unsigned char *curr_block,unsigned char *out_block, int blk_size);
+#endif
