@@ -1,4 +1,11 @@
+#include "dact.h"
+#include "config.h"
+
+#if defined(USE_MODULES) && defined(COMP_RANGE_IS_MOD) && !defined(AS_MODULE)
+#define comp_range_algo DACT_FAILED_ALGO
+#else
 int comp_range_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_range_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_range_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 void incoming_data(unsigned char value);
+#endif
