@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *      email: rkeene@netfueldesign.com
+ *      email: rkeene@rkeene.org
  */
 
 
@@ -36,6 +36,13 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
+
+#if defined(USE_MODULES) && defined(AS_MODULE)
+int DC_NUM=3;
+void *DC_ALGO=comp_text_algo;
+char *DC_NAME="Text Compression (MOD)";
+#endif
+
 int comp_text_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
