@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *      email: rkeene@netfueldesign.com
+ *      email: rkeene@rkeene.org
  */
 
 
@@ -34,18 +34,27 @@
 #include "dact.h"
 #include "algorithms.h"
 #include "endian.h"
-#ifdef CHECK_VERSION
+#include "parse.h"
+#if defined(CHECK_VERSION)
 #include "net.h"
 #endif
+#ifdef USE_MODULES
+#include "module.h"
+#endif
 
 #ifdef HAVE_GETOPT
 extern char *optarg;
 extern int optind, opterr, optopt;
 #endif
+int dact_check_ver=0;
+int dact_check_bin=1;
+
+
+
 
 int print_help(int argc, char **argv) {
-	fprintf(stderr, "DACT version %i.%i.%i by Roy Keene at Netfuel Design (rkeene@netfueldesign.com).\n\n",DACT_VER_MAJOR,DACT_VER_MINOR,DACT_VER_REVISION);
-	fprintf(stderr, "Usage:\n\tdact [-sdfv[v[v]]Clc] [-e XX] [-b XX] [--] <filename> [outfile]\n\n");
+	fprintf(stderr, "DACT version %i.%i.%i by Roy Keene at Netfuel Design (rkeene@rkeene.org).\n\n",DACT_VER_MAJOR,DACT_VER_MINOR,DACT_VER_REVISION);
+	fprintf(stderr, "Usage:\n\tdact [-sdfv[v[v]]Clc] [-e XX] [-b XX] [-m file] [--] <filename> [outfile]\n\n");
 	fprintf(stderr, "  -s\tDisplay statistics about file (Don't compress or decompress.)\n");
 	fprintf(stderr, "  -d\tDecompress instead of compressing.\n");
 	fprintf(stderr, "  -f\tForce overwriting existing files.\n");
@@ -55,24 +64,99 @@ int print_help(int argc, char **argv) {
 	fprintf(stderr, "  -c\tOutput to stdout forcefully.\n");
 	fprintf(stderr, "  -e\tExclude algorithm XX.\n");
 	fprintf(stderr, "  -b\tUse block size XX.\n");
+	fprintf(stderr, "  -m\tUse specified configuration file.\n");
 	return(0);
 }
 
+int process_config(char *filename) {
+	char *read_buf, *line_buf, *item_buf[4];
+	int fd;
+	int m,i;
+
+	if ((fd=open(filename, O_RDONLY))<0) {
+		if (strcmp(DACT_CONFIG_FILE,filename)) {
+			PRINT_LINE;
+			fprintf(stderr, "open(\"%s\"",filename);
+			perror(")");
+		}
+		return(-1);
+	}
+
+	read_buf=malloc(1024);
+
+	while (read(fd, read_buf, 1024)>0) {
+		while ( (line_buf=dact_strsep(&read_buf,"\n")) != NULL ) {
+			if (line_buf[0]=='#') line_buf[0]=0;
+			m=0;
+
+			for (i=0;i<(sizeof(item_buf)/sizeof(char *));i++) {
+				item_buf[i]=NULL;
+			}
+
+			while ((item_buf[m]=dact_strsep(&line_buf,"\t "))!=NULL) {
+				if (item_buf[m][0]!=0) {
+					if (m<(( sizeof(item_buf)/sizeof(char *) )-1)) m++;
+				}
+
+			}
+
+			if (item_buf[0]==NULL || item_buf[1]==NULL) continue;
+
+// TODO: make this work differently.
+#ifdef USE_MODULES
+			if (!strcmp("load_module",item_buf[0])) {
+				init_modules();
+				if (load_module(item_buf[1])!=DACT_MOD_OK) {
+					fprintf(stderr, "Failed to load module %s\n",item_buf[1]);
+				}
+			}
+			if (!strcmp("module_dir",item_buf[0])) {
+				strncpy(moduledirectory,item_buf[1],sizeof(moduledirectory)-1);
+			}
+#endif
+			if (!strcmp("version_check",item_buf[0])) {
+				dact_check_ver=!strcasecmp(item_buf[1],"on");
+			}
+			if (!strcmp("binary_check",item_buf[0])) {
+				dact_check_bin=!strcasecmp(item_buf[1],"on");
+			}
+		}
+	}
+
+	free(read_buf);
+
+	close(fd);
+	return(0);
+}
+
+void process_algorithms (void) {
+	int i;
+	for (i=0;i<256;i++) {
+		if (algorithms[i]==DACT_FAILED_ALGO) {
+			algorithm_names[i]="Unsupported algorithm.";
+		}
+	}
+	return;
+}
+
 
 FOUR_BYTES is_latest (void) {
-#ifdef CHECK_VERSION
+#if defined(CHECK_VERSION)
+
 	int fd;
 	char ver_maj[4]={0,0,0,0}, ver_min[4]={0,0,0,0}, ver_rev[4]={0,0,0,0};
 	char bigbuf[1024], *smallbuf;
 	int vers[3];
 	int past=0;
 
-	if (getuid()==0) return (0);
 
-	if ((fd=createconnection_tcp("keene.netfueldesign.com", 80))<0) return(0);
+	if (dact_check_ver==0) return(0);
+	if (getuid()==0) return(0);
+
+	if ((fd=createconnection_tcp("www.rkeene.org", 80))<0) return(0);
 
 	write(fd, "GET /devel/dact/VERSION HTTP/1.1\n", 33);
-	write(fd, "Host: keene.netfueldesign.com\n\n", 31);
+	write(fd, "Host: www.rkeene.org\n\n", 31);
 	read(fd, &bigbuf,1024);
 
 	strtok(bigbuf, "\n");
@@ -93,7 +177,7 @@ FOUR_BYTES is_latest (void) {
 	vers[1]=atoi(ver_min);
 	vers[2]=atoi(ver_rev);
 
-	if (vers[0]>DACT_VER_MAJOR || vers[1]>DACT_VER_MINOR || vers[2]>DACT_VER_REVISION) {
+	if ( ((vers[0]<<16)|(vers[1]<<8)|vers[2]) > ((DACT_VER_MAJOR<<16)|(DACT_VER_MINOR<<8)|DACT_VER_REVISION) ) {
 		return((vers[0]<<16)|(vers[1]<<8)|vers[2]);
 	} else {
 		return(0);
@@ -106,7 +190,7 @@ FOUR_BYTES is_latest (void) {
 
 
 int main(int argc, char **argv) {
-	char in_filename[128], out_filename[128];
+	char in_filename[128], out_filename[128], cfg_filename[128];
 	char in_buffer[MAX_DACT_BLK_SIZE], prev_buffer[MAX_DACT_BLK_SIZE];
 	char out_buffer[MAX_DACT_BLK_SIZE*2];
 	char store_buffer[MAX_DACT_BLK_SIZE*2];
@@ -118,7 +202,7 @@ int main(int argc, char **argv) {
 	char option_old=0;
 	char ch;
 	FOUR_BYTES file_size_real=0, file_size, out_file_size, in_magic;
-#ifdef CHECK_VERSION
+#if defined(CHECK_VERSION)
 	FOUR_BYTES version_latest;
 #endif
 	int stat_cnt[256];
@@ -143,31 +227,12 @@ int main(int argc, char **argv) {
 	option_verbose=1;
 #endif
 
-#ifdef CHECK_VERSION
-/* 
-  This checks for ~/.dact/dact.bin, and executes it
-*/
-#ifndef GO32
-	strcpy(in_filename,getenv("HOME"));
-	strcat(in_filename,"/.dact/dact.bin");
 
-	if (strcmp(argv[0],in_filename)) {
-		if (access(in_filename,X_OK)==0) {
-			argv[0]=in_filename;
-			execv(in_filename,argv);
-		}
-	}
-#endif
-
-	if ((version_latest=is_latest())!=0) {
-		fprintf(stderr, "\033[1mNOTE:\n");
-		fprintf(stderr, "  There is a newer version of DACT: %i.%i.%i\n", version_latest>>16, (version_latest>>8)&0xff, version_latest&0xff);
-		fprintf(stderr, "  http://keene.netfueldesign.com/devel/dact.tar.gz is the latest version.\033[0m\n\n");
-	}
-#endif
+	strcpy(cfg_filename,DACT_CONFIG_FILE);
+	process_algorithms();
 
 #ifdef HAVE_GETOPT
-	while ((ch = getopt(argc,argv,"dfvClshce:b:")) != -1) {
+	while ((ch = getopt(argc,argv,"dfvClshce:b:m:")) != -1) {
 #else
 	for (optind=1;optind<argc;optind++) {
 		if (argv[optind][0]=='-' && argv[optind][1]!='-') {
@@ -198,12 +263,16 @@ int main(int argc, char **argv) {
 				}
 				break;
 			case 'l':
+				process_config(cfg_filename);
 				fprintf(stderr, " Number | Algorithm Name\n");
 				fprintf(stderr, "--------+----------------------------------------------------------------------\n");
 				for (i=0;i<256;i++) {
 					if (algorithms[i]==NULL) break;
 					fprintf(stderr, "    %03i | %s\n",i,algorithm_names[i]);
 				}
+#ifdef USE_MODULES
+				unload_modules();
+#endif
 				return(0);
 			case 'e':
 				if (optarg!=NULL) {
@@ -220,6 +289,9 @@ int main(int argc, char **argv) {
 			case 'h':
 				print_help(argc,argv);
 				return(0);
+			case 'm':
+				strncpy(cfg_filename,optarg,sizeof(cfg_filename)-1);
+				break;
 			case ':':
 			case '?':
 				fprintf(stderr, "%s: Try %s -h for help.\n",argv[0], argv[0]);
@@ -229,6 +301,35 @@ int main(int argc, char **argv) {
 	}
 
 
+	process_config(cfg_filename);
+
+/* 
+  This checks for ~/.dact/dact.bin, and executes it
+*/
+#ifndef GO32
+	if (dact_check_bin) {
+		strcpy(in_filename,getenv("HOME"));
+		strcat(in_filename,"/.dact/dact.bin");
+
+		if (strcmp(argv[0],in_filename)) {
+			if (access(in_filename,X_OK)==0) {
+				argv[0]=in_filename;
+				execv(in_filename,argv);
+			}
+		}
+	}
+#endif
+
+#if defined(CHECK_VERSION)
+
+	if ((version_latest=is_latest())!=0) {
+		fprintf(stderr, "\033[1mNOTE:\n");
+		fprintf(stderr, "  There is a newer version of DACT: %i.%i.%i\n", version_latest>>16, (version_latest>>8)&0xff, version_latest&0xff);
+		fprintf(stderr, "  http://www.rkeene.org/devel/dact.tar.gz is the latest version.\033[0m\n\n");
+	}
+#endif
+
+
 	for (i=0;i<sizeof(prev_buffer);i++) prev_buffer[i]=0;
 	for (i=0;i<256;i++) stat_cnt[i]=0;
 
@@ -243,6 +344,9 @@ int main(int argc, char **argv) {
 	} else { 
 		if ((in_fd=open(in_filename,O_RDONLY))==-1) {
 			fprintf(stderr, "%s: Unable to open %s for reading.\n",argv[0],in_filename);
+#ifdef USE_MODULES
+			unload_modules();
+#endif
 			return(-1);
 		}
 	}
@@ -253,6 +357,9 @@ int main(int argc, char **argv) {
 		} else {
 			if (isatty(STDOUT_FILENO)) {
 				if (isatty(in_fd)) {
+#ifdef USE_MODULES
+					unload_modules();
+#endif
 					return(print_help(argc,argv));
 				}
 				if (mode==DACT_MODE_COMPR) {
@@ -275,12 +382,18 @@ int main(int argc, char **argv) {
 				} else {
 					fprintf(stderr, "%s: %s exists, exiting.\n",argv[0],out_filename);
 					close(in_fd);
+#ifdef USE_MODULES
+					unload_modules();
+#endif
 					return(-1);
 				}
 			}
 	
 			if ((out_fd=open(out_filename,O_WRONLY|O_CREAT,0644))==-1) {
 				fprintf(stderr, "%s: Unable to open %s for writing.\n",argv[0],out_filename);
+#ifdef USE_MODULES
+				unload_modules();
+#endif
 				return(-1);
 			}
 		}
@@ -340,7 +453,11 @@ int main(int argc, char **argv) {
 					memcpy(prev_buffer,in_buffer,DACT_BLK_SIZE);
 				}
 				if (out_lowest==(DACT_BLK_SIZE*2)) {
+					PRINT_LINE;
 					fprintf(stderr, "Compression resulted in DACT_BLK_SIZE*2 !  Aborting.\n");
+#ifdef USE_MODULES
+					unload_modules();
+#endif
 					return(-1);
 				}
 				if (option_verbose>1) {
@@ -377,6 +494,9 @@ int main(int argc, char **argv) {
 
 			if (in_magic!=DACT_MAGIC_NUMBER && mode_force<2) {
 				printf("%s: Bad magic.\n", argv[0]);
+#ifdef USE_MODULES
+				unload_modules();
+#endif
 				return(-1);
 			}
 
@@ -396,6 +516,9 @@ int main(int argc, char **argv) {
 				fprintf(stderr, "File is not usable, exiting...\n");
 				close(in_fd);
 				close(out_fd);
+#ifdef USE_MODULES
+				unload_modules();
+#endif
 				return(-1);
 			}
 			if (file_version[1]!=DACT_VER_MINOR || file_version[2]!=DACT_VER_REVISION) {
@@ -418,6 +541,9 @@ int main(int argc, char **argv) {
 					fprintf(stderr, "Request for an unknown algorithm: %i\n", header.algo);
 					close(in_fd);
 					close(out_fd);
+#ifdef USE_MODULES
+					unload_modules();
+#endif
 					return(-1);
 				}
 				out_size=algorithms[header.algo](DACT_MODE_DECMP, &prev_buffer, &in_buffer, &out_buffer, header.size);
@@ -425,6 +551,9 @@ int main(int argc, char **argv) {
 					fprintf(stderr, "Block resulted in data that is less than %i bytes (=%i).\n",DACT_BLK_SIZE,out_size);
 					close(in_fd);
 					close(out_fd);
+#ifdef USE_MODULES
+					unload_modules();
+#endif
 					return(-1);
 				}
 				if (option_verbose>1) {
@@ -471,6 +600,9 @@ int main(int argc, char **argv) {
 				printf(" (Bad magic.)\n");
 				close(in_fd);
 				close(out_fd);
+#ifdef USE_MODULES
+				unload_modules();
+#endif
 				return(-1);
 			} else {
 				printf("\n");
@@ -510,5 +642,8 @@ int main(int argc, char **argv) {
 	close(out_fd);
 
 	if (option_verbose==1 && mode!=DACT_MODE_STAT) fprintf(stderr, "\n");
+#ifdef USE_MODULES
+	unload_modules();
+#endif
 	return(0);
 }
