@@ -1,8 +1,10 @@
+#include "config.h"
+
 #ifndef _DACT_H
 #define _DACT_H
 #define DACT_VER_MAJOR 0
-#define DACT_VER_MINOR 4
-#define DACT_VER_REVISION 15
+#define DACT_VER_MINOR 5
+#define DACT_VER_REVISION 0
 
 #define DACT_MODE_COMPR 1
 #define DACT_MODE_DECMP 2
@@ -10,6 +12,14 @@
 
 #define MAX_DACT_BLK_SIZE 16384
 
+#ifndef DACT_CONFIG_FILE
+#if defined(__WIN32__) || defined(GO32)
+#define DACT_CONFIG_FILE "c:/dact.cfg"
+#else
+#define DACT_CONFIG_FILE "/etc/dact.conf"
+#endif
+#endif
+
 #if defined(__WIN32__) || defined(GO32)
 #ifndef TWO_BYTES
 #define TWO_BYTES unsigned int
@@ -42,3 +52,14 @@ TWO_BYTES DACT_BLK_SIZE=4088;
 extern TWO_BYTES DACT_BLK_SIZE;
 #endif
 #endif
+
+
+#if defined(__FILE__) && defined(__LINE__)
+#define PRINT_LINE fprintf(stderr, __FILE__ ":%i: ", __LINE__)
+#else
+#define PRINT_LINE /**/
+#endif
+
+#ifndef DACT_FAILED_ALGO
+#define DACT_FAILED_ALGO comp_fail_algo
+#endif
