@@ -42,7 +42,11 @@ int createconnection_tcp(char *host, int port) {
 	struct hostent *hostinfo;
 	struct sockaddr_in sock;
 	if ((hostinfo=gethostbyname(host))==NULL) {
+#ifdef USE_ADDR
+		if ( (sock.sin_addr.s_addr=inet_addr(host) )==-1)
+#else
 		if (!inet_aton(host,&sock.sin_addr))
+#endif
 			return(-1);
 	} else {
 		memcpy(&sock.sin_addr.s_addr,hostinfo->h_addr_list[0],hostinfo->h_length);
